Clean physician identification numbers
clean_physician_id(physician, keep_unknown = FALSE)A character vector with leading and trailing whitespace removed.
If keep_unknown is FALSE, blanks and values representing
unknown physicians or non-applicable are replaced with NA.
A character vector of medical license number or facility-generated codes.
Replace values for "unknown" with NA?