These lists gives the levels for each categorical or flag field from the NAACCR formats. It is intended to help researchers
field_levelsfield_levels_all
A named list, where the names are for categorical fields or
sentinel flags, and the values are the possible levels for each field.
An object of class list of length 340.
field_levels does not include levels representing "unknown."
field_levels_all does include the "unknown" levels.