A POSIXct vector. Any incomplete or invalid datetimes are
converted to NA. The original strings can be retrieved with the
naaccr_encode function.
Arguments
datetime
Character vector of datetimes in HL7 OBR-7 format
("YYYYMMDDHHMMSS") or the ISO 8601 format for datetimes accurate to
the second (YYYY-MM-DDThh:mm:ss+zz:zz).
Values containing a hyphen ("-") will be assumed to follow ISO 8601,
and other values will be assumed to follow HL7 OBR-7.
tz
time zone specification to be used for the conversion,
if one is required. System-specific (see time zones),
but "" is the current time zone, and "GMT" is UTC
(Universal Time, Coordinated). Invalid values are most commonly
treated as UTC, on some platforms with a warning.