Subclass of data.frame for doing analysis with NAACCR records.
naaccr_record(..., keep_unknown = FALSE, version = NULL, format = NULL)A naaccr_record with columns named using the NAACCR XML scheme.
It inherits from data.frame.
Arguments of the form tag = value, where tag is a
valid NAACCR data item name and value is the vector of the item's
values from the NAACCR format.
Logical indicating whether values of "unknown" should be
a level in the factor or NA.
An integer specifying the NAACCR format version for parsing
the records. Use this or format, not both. If both version
and format are NULL (default), the most recent NAACCR format
will be used.
A record_format object for parsing the records.
naaccr_record creates a data.frame of cancer incidence records
ready for analysis:
columns are of appropriate classes, coded values are replaced with factors,
and unknowns are replaced with NA.