Write records from a naaccr_record object to a connection in
fixed-width format, according to a specific version of the NAACCR format.
write_naaccr(records, con, version = NULL, format = NULL, encoding = "UTF-8")A naaccr_record object.
Either a character string naming a file or a
connection open for writing.
An integer specifying the NAACCR format version for parsing
the records. Use this or format, not both. If both version
and format are NULL (the default), the most recent version is
used.
A record_format object for writing the records.
String specifying the character encoding for the output file.