Write records to a NAACCR-formatted XML file
write_naaccr_xml(
records,
con,
version = NULL,
format = NULL,
base_dictionary = NULL,
user_dictionary = NULL,
encoding = "UTF-8"
)A naaccr_record object.
Either a character string naming a file or a
connection open for writing.
An integer specifying the NAACCR format version for parsing
the records. Use this or format, not both. If both version
and format are NULL (the default), the most recent version is
used.
A record_format object for writing the records.
URI for the dictionary defining the NAACCR data items.
If this is NULL and either version is not NULL or
format is one of the standard NAACCR formats, then the URI from
NAACCR's website for that version's dictionary will be used.
URI for the dictionary defining the user-specified
data items. If NULL (default), it won't be included in the XML.
String specifying the character encoding for the output file.